Package: DEGraph
Title: Two-sample tests on a graph
Version: 1.64.0
Date: 2012-04-27
Author: Laurent Jacob, Pierre Neuvial and Sandrine Dudoit
Maintainer: Laurent Jacob <laurent.jacob@gmail.com>
Description: DEGraph implements recent hypothesis testing methods which
        directly assess whether a particular gene network is
        differentially expressed between two conditions. This is to be
        contrasted with the more classical two-step approaches which
        first test individual genes, then test gene sets for enrichment
        in differentially expressed genes. These recent methods take
        into account the topology of the network to yield more powerful
        detection procedures. DEGraph provides methods to easily test
        all KEGG pathways for differential expression on any gene
        expression data set and tools to visualize the results.
License: GPL-3
LazyLoad: yes
Imports: graph, KEGGgraph, lattice, mvtnorm, R.methodsS3, RBGL,
        Rgraphviz, rrcov, NCIgraph
Suggests: corpcor, fields, graph, KEGGgraph, lattice, marray, RBGL,
        rrcov, Rgraphviz, NCIgraph
Depends: R (>= 2.10.0), R.utils
biocViews: Microarray, DifferentialExpression, GraphAndNetwork,
        Network, NetworkEnrichment, DecisionTree
git_url: https://git.bioconductor.org/packages/DEGraph
git_branch: RELEASE_3_23
git_last_commit: e996aea
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:38:56 UTC; biocbuild
